@@ -1,10 +1,9 @@
 #include <stdio.h>
 
-extern char *dirpath[], *suffixes[];
 char pathname[1024];
 
 /* find input file; leave name in pathname[] */
-FILE *findfile(char *fnam) {
+FILE *findfile(char *fnam, char **dirpath, char **suffixes) {
         char **dp, **sp;
 	FILE *fp;
 
