@@ -9,6 +9,8 @@
 #include <sys/ioctl.h>
 #include <linux/kd.h>
 
+extern int getfd(void);
+
 void
 usage(void) {
     fprintf(stderr, "usage: getkeycodes\n");
@@ -22,8 +24,7 @@ main(int argc, char **argv) {
 
     if (argc != 1)
       usage();
-    if ((fd = open("/dev/console", 0)) < 0)
-      fd = 0;
+    fd = getfd();
     printf("Plain scancodes xx (hex) versus keycodes (dec)\n");
     printf("0 is an error; for 1-88 (0x01-0x58) scancode equals keycode\n");
 
