@@ -712,7 +712,8 @@ static char *spec_syms[] = {
 	"SAK",
 	"Decr_Console",
 	"Incr_Console",
-	"Spawn_Console"
+	"Spawn_Console",
+	"Bare_Num_Lock"
 };
 
 static char *pad_syms[] = {
