@@ -25,13 +25,13 @@ static char *mapdirpath[] = { "", DATADIR "/" TRANSDIR "/", 0 };
 static char *mapsuffixes[] = { "", 0 };
 
 #ifdef MAIN
+extern int getfd(void);
+
 int
 main(int argc, char *argv[]) {
 	int fd;
 
-	/* we do not want to read, but only need some fd */
-	if ((fd = open("/dev/console", 0)) < 0)
-	    fd = 0;
+	fd = getfd();
 
 	if (argc >= 3 && !strcmp(argv[1], "-o")) {
 	    saveoldmap(fd, argv[2]);
@@ -85,8 +85,6 @@ loadnewmap(int fd, char *mfil) {
 	}
 	fclose(fp);
 
-	memset(buf,0,32); /* don't redefine control characters */
-
 	i = ioctl(fd,PIO_SCRNMAP,buf);
 	if (i) {
 	    perror("PIO_SCRNMAP ioctl error");
