@@ -1,7 +1,7 @@
 /*
  * setfont.c - Eugene Crosser & Andries Brouwer
  *
- * Version 0.90
+ * Version 0.91
  *
  * Loads the console font, and possibly the corresponding screen map(s).
  * We accept two kind of screen maps, one [-m] giving the correspondence
@@ -17,7 +17,6 @@
 #include <sys/stat.h>
 #include <sys/ioctl.h>
 #include <sys/kd.h>
-#include <malloc.h> /* just to be sure */
 #include "paths.h"
 #include "psf.h"
 
@@ -31,6 +30,8 @@ extern void loadnewmap(int fd, char *mfil);
 extern void saveunicodemap(int fd, char *oufil);
 extern void loadunicodemap(int fd, char *ufil);
 extern void activatemap(void);
+extern int getfd(void);
+extern char *malloc();
 
 /* search for the font in these directories (with trailing /) */
 char *fontdirpath[] = { "", DATADIR "/" FONTDIR "/", 0 };
@@ -69,9 +70,7 @@ main(int argc, char *argv[])
 
 	progname = argv[0];
 
-	/* we do not want to read, but only need some fd */
-	if ((fd = open("/dev/console", 0)) < 0)
-	  fd = 0;
+	fd = getfd();
 
 	ifil = mfil = ufil = ofil = omfil = oufil = 0;
 	iunit = 0;
@@ -147,8 +146,8 @@ main(int argc, char *argv[])
 }
 
 void
-do_loadfont(int fd, int unit, FILE *fpi) {
-	char buf[8192];
+do_loadfont(int fd, int unit, int fontsize, FILE *fpi) {
+	char buf[16384];
 	int i;
 
 	memset(buf,0,sizeof(buf));
@@ -158,14 +157,27 @@ do_loadfont(int fd, int unit, FILE *fpi) {
 	    exit(1);
 	}
 
-	for (i = 0; i < 256; i++)
+	for (i = 0; i < fontsize; i++)
 	  if (fread(buf+(32*i), unit, 1, fpi) != 1) {
 	      perror("Cannot read font from file");
 	      exit(1);
 	  }
 
-	fprintf(stderr,"Loading 8x%d font from file %s\n", unit, pathname);
+	fprintf(stderr, "Loading 8x%d font from file %s\n", unit, pathname);
 
+#ifdef PIO_FONTX
+	{
+	    struct consolefontdesc cfd;
+
+	    cfd.charcount = fontsize;
+	    cfd.charheight = unit;
+	    cfd.chardata = buf;
+
+	    if (ioctl(fd,PIO_FONTX,&cfd) == 0)
+	      return;		/* success */
+	    perror("PIO_FONTX ioctl error (trying PIO_FONT)");
+	}
+#endif
 	if (ioctl(fd,PIO_FONT,buf)) {
 	    perror("PIO_FONT ioctl error");
 	    exit(1);
@@ -208,10 +220,12 @@ do_loadtable(int fd, int tailsz, int fontsize, FILE *fpi) {
 	advice.advised_hashstep = 0;
 	advice.advised_hashlevel = 0;
 	if(ioctl(fd, PIO_UNIMAPCLR, &advice)) {
+#ifdef ENOIOCTLCMD
 	    if (errno == ENOIOCTLCMD) {
 		fprintf(stderr, "It seems this kernel is older than 1.1.92\n");
 		fprintf(stderr, "No Unicode mapping table loaded.\n");
 	    } else
+#endif
 	      perror("PIO_UNIMAPCLR");
 	    exit(1);
 	}
@@ -289,10 +303,12 @@ loadnewfont(int fd, char *ifil, int iunit, int no_m, int no_u) {
 		exit(1);
 	    }
 	    fontsize = ((psfhdr.mode & PSF_MODE512) ? 512 : 256);
+#ifndef PIO_FONTX
 	    if (fontsize != 256) {
 		fprintf(stderr, "Only fontsize 256 supported\n");
 		exit(1);
 	    }
+#endif
 	    hastable = (psfhdr.mode & PSF_MODEHASTAB);
 	    unit = psfhdr.charsize;
 	    head = sizeof(struct psf_header) + fontsize*unit;
@@ -300,7 +316,7 @@ loadnewfont(int fd, char *ifil, int iunit, int no_m, int no_u) {
 		fprintf(stderr, "Input file: bad length\n");
 		exit(1);
 	    }
-	    do_loadfont(fd, unit, fpi);
+	    do_loadfont(fd, unit, fontsize, fpi);
 	    if (hastable && !no_u)
 	      do_loadtable(fd, size-head, fontsize, fpi);
 	    fclose(fpi);
@@ -320,7 +336,7 @@ loadnewfont(int fd, char *ifil, int iunit, int no_m, int no_u) {
 	    }
 	    unit = size/256;
 	}
-	do_loadfont(fd, unit, fpi);
+	do_loadfont(fd, unit, 256, fpi);
 	fclose(fpi);
 }
 
