@@ -8,12 +8,13 @@
 #include <linux/keyboard.h>
 #include <sys/ioctl.h>
 
-#define VERSION "0.90"
+#define VERSION "0.91"
 
 int tmp;	/* for debugging */
 
 #define OPTION "medium raw"
 
+extern int getfd();
 int fd;
 int oldkbmode;
 struct termios old;
@@ -118,6 +119,8 @@ main (int argc, char *argv[]) {
 	if (optind < argc)
 		usage();
 
+	fd = getfd();
+
 	/* the program terminates when there is no input for 10 secs */
 	signal(SIGALRM, watch_dog);
 
@@ -147,10 +150,6 @@ main (int argc, char *argv[]) {
 	signal(SIGTTIN, die);
 	signal(SIGTTOU, die);
 
-	if ((fd = open("/dev/console", O_RDONLY)) < 0) {
-		perror("/dev/console");
-		exit(1);
-	}
 	get_mode();
 	tmp = tcgetattr(fd, &old);
 	if (tmp)
